@@ -1,6 +1,9 @@
 # -*- coding: utf-8 -*-
 from copy import deepcopy
+from design.plone.policy.setuphandlers import disable_searchable_types
 from plone.app.upgrade.utils import installOrReinstallProduct
+from design.plone.policy.interfaces import IDesignPlonePolicySettings
+
 from plone import api
 
 import logging
@@ -76,3 +79,19 @@ def to_1200(context):
             logger.info("- {}".format(fixed))
     else:
         logger.info("No items affected.")
+
+
+def to_1300(context):
+    disable_searchable_types()
+
+
+def to_1400(context):
+    old = api.portal.get_registry_record(
+        name="design.plone.policy.twitter_token"
+    )
+    context.runAllImportStepsFromProfile("profile-design.plone.policy:to_1400")
+    update_registry(context)
+
+    api.portal.set_registry_record(
+        "twitter_token", old, interface=IDesignPlonePolicySettings
+    )
